Crate tauri_plugin_fs

Crate tauri_plugin_fs 

Access the file system.

Cargo features

  • watch: Enables the watch command backed by notify.

Structs

Fs
Access to the file system APIs on desktop.
OpenOptions
Options and flags which can be used to configure how a file is opened.

Enums

Error
Errors that can happen while using the file system plugin.
FilePath
Represents either a filesystem path or a URI pointing to a file such as file:// URIs or Android content:// URIs.
SafeFilePath
Represents either a safe filesystem path or a URI pointing to a file such as file:// URIs or Android content:// URIs.

Traits

FsExt
Extension trait implemented by every Manager (the app handle, windows, webviews, …) to access the file system plugin APIs.

Functions

init
Initializes the plugin.